@@ -132,7 +132,7 @@ int GPTDataTextUI::XFormDisklabel(void) {
       numDone = GPTData::XFormDisklabel(partNum);
 
    return numDone;
-} // GPTData::XFormDisklabel(int i)
+} // GPTData::XFormDisklabel(void)
 
 
 /*********************************************************************
@@ -452,7 +452,7 @@ void GPTDataTextUI::MakeHybrid(void) {
       if (eeFirst == 'Y') {
          hybridMBR.AddPart(0, hybridPart);
       } else {
-         hybridMBR.AddPart(3, hybridPart);
+         hybridMBR.AddPart(numPartsToCvt, hybridPart);
       } // else
       hybridMBR.SetHybrid();
 
